﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Tsi1.BusinessLayer.Dtos;
using Tsi1.BusinessLayer.Helpers;
using Tsi1.BusinessLayer.Interfaces;

namespace Tsi1.Api.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class TenantController : ControllerBase
    {
        private readonly ITenantService _tenantService;

        private readonly IFileService _fileService;

        public TenantController(ITenantService tenantService, IFileService fileService)
        {
            _tenantService = tenantService;
            _fileService = fileService;
        }

        [Authorize(Roles = UserTypes.UdelarAdmin)]
        [HttpGet("GetAll")]
        public async Task<IActionResult> GetAll()
        {
            var result = await _tenantService.GetAll();

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.UdelarAdmin)]
        [HttpPost("Create")]
        public async Task<IActionResult> Create(TenantCreateDto newTenant)
        {
            var result = await _tenantService.Create(newTenant);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            _fileService.CreateFolder(result.Data.Id.ToString());

            return Ok(result.Data);
        }

        [Authorize(Roles = UserTypes.UdelarAdmin)]
        [HttpPut("Modify/{tenantId}")]
        public async Task<IActionResult> Modify(int tenantId, TenantCreateDto tenantDto)
        {
            var result = await _tenantService.Modify(tenantId, tenantDto);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            if (result.Data == false)
            {
                return NotFound(result.Message);
            }

            return Ok();
        }

        [Authorize(Roles = UserTypes.UdelarAdmin)]
        [HttpDelete("Delete/{tenantId}")]
        public async Task<IActionResult> Delete(int tenantId)
        {
            var result = await _tenantService.Delete(tenantId);

            if (result.HasError)
            {
                return BadRequest(result.Message);
            }

            if (result.Data == false)
            {
                return NotFound(result.Message);
            }

            _fileService.DeleteFolder(tenantId.ToString());

            return Ok();
        }
    }
}
